@@ -1,5 +1,5 @@
 from textual.app import App
-from textual.containers import Container
+from textual.containers import ScrollableContainer
 from textual.widgets import Label
 
 TEXT = """I must not fear.
@@ -14,7 +14,7 @@ Where the fear has gone there will be nothing. Only I will remain.
 
 class ScrollbarApp(App):
     def compose(self):
-        yield Container(Label(TEXT * 5), classes="panel")
+        yield ScrollableContainer(Label(TEXT * 5), classes="panel")
 
 
 app = ScrollbarApp(css_path="scrollbar_size.css")
