@@ -1,5 +1,5 @@
 from textual.app import App
-from textual.containers import Horizontal, Container
+from textual.containers import Horizontal, ScrollableContainer
 from textual.widgets import Label
 
 TEXT = """I must not fear.
@@ -15,10 +15,12 @@ Where the fear has gone there will be nothing. Only I will remain.
 class ScrollbarApp(App):
     def compose(self):
         yield Horizontal(
-            Container(Label(TEXT * 5), id="v1"),
-            Container(Label(TEXT * 5), id="v2"),
-            Container(Label(TEXT * 5), id="v3"),
+            ScrollableContainer(Label(TEXT * 5), id="v1"),
+            ScrollableContainer(Label(TEXT * 5), id="v2"),
+            ScrollableContainer(Label(TEXT * 5), id="v3"),
         )
 
 
 app = ScrollbarApp(css_path="scrollbar_size2.css")
+if __name__ == "__main__":
+    app.run()
