@@ -139,12 +139,11 @@ class BoundAnimator:
             attribute: Name of the attribute to animate.
             value: The value to animate to.
             final_value: The final value of the animation. Defaults to `value` if not set.
-            duration: The duration of the animate. Defaults to None.
-            speed: The speed of the animation. Defaults to None.
-            delay: A delay (in seconds) before the animation starts. Defaults to 0.0.
-            easing: An easing method. Defaults to "in_out_cubic".
-            on_complete: A callable to invoke when the animation is finished. Defaults to None.
-
+            duration: The duration of the animate.
+            speed: The speed of the animation.
+            delay: A delay (in seconds) before the animation starts.
+            easing: An easing method.
+            on_complete: A callable to invoke when the animation is finished.
         """
         start_value = getattr(self._obj, attribute)
         if isinstance(value, str) and hasattr(start_value, "parse"):
@@ -197,7 +196,7 @@ class Animator:
         """Start the animator task."""
         self._idle_event.set()
         self._complete_event.set()
-        self._timer.start()
+        self._timer._start()
 
     async def stop(self) -> None:
         """Stop the animator task."""
@@ -237,11 +236,11 @@ class Animator:
             obj: The object containing the attribute.
             attribute: The name of the attribute.
             value: The destination value of the attribute.
-            final_value: The final value, or ellipsis if it is the same as ``value``. Defaults to Ellipsis/
-            duration: The duration of the animation, or ``None`` to use speed. Defaults to ``None``.
-            speed: The speed of the animation. Defaults to None.
-            easing: An easing function. Defaults to DEFAULT_EASING.
-            delay: Number of seconds to delay the start of the animation by. Defaults to 0.
+            final_value: The final value, or ellipsis if it is the same as ``value``.
+            duration: The duration of the animation, or ``None`` to use speed.
+            speed: The speed of the animation.
+            easing: An easing function.
+            delay: Number of seconds to delay the start of the animation by.
             on_complete: Callback to run after the animation completes.
         """
         animate_callback = partial(
@@ -280,10 +279,10 @@ class Animator:
             obj: The object containing the attribute.
             attribute: The name of the attribute.
             value: The destination value of the attribute.
-            final_value: The final value, or ellipsis if it is the same as ``value``. Defaults to ....
-            duration: The duration of the animation, or ``None`` to use speed. Defaults to ``None``.
-            speed: The speed of the animation. Defaults to None.
-            easing: An easing function. Defaults to DEFAULT_EASING.
+            final_value: The final value, or ellipsis if it is the same as ``value``.
+            duration: The duration of the animation, or ``None`` to use speed.
+            speed: The speed of the animation.
+            easing: An easing function.
             on_complete: Callback to run after the animation completes.
         """
         if not hasattr(obj, attribute):
