@@ -2,11 +2,12 @@ from __future__ import annotations
 
 from functools import lru_cache
 from sys import intern
-from typing import TYPE_CHECKING, Callable, Iterable
+from typing import TYPE_CHECKING, Callable, Iterable, Sequence
 
 from rich.console import Console
 from rich.segment import Segment
 from rich.style import Style
+from rich.text import Text
 
 from ._border import get_box, render_border_label, render_row
 from ._opacity import _apply_opacity
@@ -64,7 +65,6 @@ class StylesCache:
     ┃                      ┃
     ┗━━━━━━━━━━━━━━━━━━━━━━┛
     ```
-
     """
 
     def __init__(self) -> None:
@@ -106,6 +106,10 @@ class StylesCache:
         Returns:
             Rendered lines.
         """
+
+        border_title = widget._border_title
+        border_subtitle = widget._border_subtitle
+
         base_background, background = widget.background_colors
         styles = widget.styles
         strips = self.render(
@@ -115,12 +119,26 @@ class StylesCache:
             background,
             widget.render_line,
             widget.app.console,
-            widget.border_title,
-            widget.border_subtitle,
+            (
+                None
+                if border_title is None
+                else (
+                    border_title,
+                    *widget._get_title_style_information(base_background),
+                )
+            ),
+            (
+                None
+                if border_subtitle is None
+                else (
+                    border_subtitle,
+                    *widget._get_subtitle_style_information(base_background),
+                )
+            ),
             content_size=widget.content_region.size,
             padding=styles.padding,
             crop=crop,
-            filter=widget.app._filter,
+            filters=widget.app._filters,
         )
         if widget.auto_links:
             hover_style = widget.hover_style
@@ -146,12 +164,12 @@ class StylesCache:
         background: Color,
         render_content_line: RenderLineCallback,
         console: Console,
-        border_title: str,
-        border_subtitle: str,
+        border_title: tuple[Text, Color, Color, Style] | None,
+        border_subtitle: tuple[Text, Color, Color, Style] | None,
         content_size: Size | None = None,
         padding: Spacing | None = None,
         crop: Region | None = None,
-        filter: LineFilter | None = None,
+        filters: Sequence[LineFilter] | None = None,
     ) -> list[Strip]:
         """Render a widget content plus CSS styles.
 
@@ -162,12 +180,12 @@ class StylesCache:
             background: Background color of widget.
             render_content_line: Callback to render content line.
             console: The console in use by the app.
-            border_title: The title for the widget border.
-            border_subtitle: The subtitle for the widget border.
+            border_title: Optional tuple of (title, color, background, style).
+            border_subtitle: Optional tuple of (subtitle, color, background, style).
             content_size: Size of content or None to assume full size.
             padding: Override padding from Styles, or None to use styles.padding.
             crop: Region to crop to.
-            filter: Additional post-processing for the segments.
+            filters: Additional post-processing for the segments.
 
         Returns:
             Rendered lines.
@@ -206,8 +224,9 @@ class StylesCache:
                 self._cache[y] = strip
             else:
                 strip = self._cache[y]
-            if filter:
-                strip = strip.apply_filter(filter)
+            if filters:
+                for filter in filters:
+                    strip = strip.apply_filter(filter, background)
             add_strip(strip)
         self._dirty_lines.difference_update(crop.line_range)
 
@@ -228,8 +247,8 @@ class StylesCache:
         background: Color,
         render_content_line: Callable[[int], Strip],
         console: Console,
-        border_title: str,
-        border_subtitle: str,
+        border_title: tuple[Text, Color, Color, Style] | None,
+        border_subtitle: tuple[Text, Color, Color, Style] | None,
     ) -> Strip:
         """Render a styled line.
 
@@ -243,8 +262,8 @@ class StylesCache:
             background: Background color of widget.
             render_content_line: Callback to render a line of content.
             console: The console in use by the app.
-            border_title: The title for the widget border.
-            border_subtitle: The subtitle for the widget border.
+            border_title: Optional tuple of (title, color, background, style).
+            border_subtitle: Optional tuple of (subtitle, color, background, style).
 
         Returns:
             A line of segments.
@@ -284,8 +303,6 @@ class StylesCache:
             Returns:
                 New list of segments
             """
-            if styles.text_opacity != 1.0:
-                segments = TextOpacity.process_segments(segments, styles.text_opacity)
             if styles.tint.a:
                 segments = Tint.process_segments(segments, styles.tint)
             if styles.opacity != 1.0:
@@ -304,13 +321,29 @@ class StylesCache:
             has_left = border_left != ""
             has_right = border_right != ""
             border_label = border_title if is_top else border_subtitle
+            if border_label is None:
+                render_label = None
+            else:
+                label, label_color, label_background, style = border_label
+                base_label_background = base_background + background
+                style += Style.from_color(
+                    (
+                        (base_label_background + label_color).rich_color
+                        if label_color.a
+                        else None
+                    ),
+                    (base_label_background + label_background).rich_color
+                    if label_background.a
+                    else None,
+                )
+                render_label = (label, style)
             # Try to save time with expensive call to `render_border_label`:
-            if border_label:
+            if render_label:
                 label_segments = render_border_label(
-                    border_label,
+                    render_label,
                     is_top,
                     border_edge_type,
-                    width,
+                    width - 2,
                     inner,
                     outer,
                     border_color_as_style,
@@ -369,6 +402,8 @@ class StylesCache:
                 line = [make_blank(content_width, inner)]
             if inner:
                 line = Segment.apply_style(line, inner)
+            if styles.text_opacity != 1.0:
+                line = TextOpacity.process_segments(line, styles.text_opacity)
             line = line_pad(line, pad_left, pad_right, inner)
 
             if border_left or border_right:
