@@ -1,3 +1,11 @@
+"""
+
+A binding maps a key press on to an action.
+
+See [bindings](/guide/input#bindings) in the guide for details.
+"""
+
+
 from __future__ import annotations
 
 from dataclasses import dataclass
@@ -44,7 +52,7 @@ class Binding:
 
 
 @rich.repr.auto
-class Bindings:
+class _Bindings:
     """Manage a set of bindings."""
 
     def __init__(
@@ -98,13 +106,13 @@ class Bindings:
             else {}
         )
 
-    def copy(self) -> Bindings:
+    def copy(self) -> _Bindings:
         """Return a copy of this instance.
 
         Return:
             New bindings object.
         """
-        copy = Bindings()
+        copy = _Bindings()
         copy.keys = self.keys.copy()
         return copy
 
@@ -112,7 +120,7 @@ class Bindings:
         yield self.keys
 
     @classmethod
-    def merge(cls, bindings: Iterable[Bindings]) -> Bindings:
+    def merge(cls, bindings: Iterable[_Bindings]) -> _Bindings:
         """Merge a bindings. Subsequent bound keys override initial keys.
 
         Args:
@@ -124,7 +132,7 @@ class Bindings:
         keys: dict[str, Binding] = {}
         for _bindings in bindings:
             keys.update(_bindings.keys)
-        return Bindings(keys.values())
+        return _Bindings(keys.values())
 
     @property
     def shown_keys(self) -> list[Binding]:
