@@ -1,13 +1,11 @@
 """
-This module contains a powerful Color class which Textual uses to expose colors.
-
-The only exception would be for Rich renderables, which require a rich.color.Color instance.
-You can convert from a Textual color to a Rich color with the [rich_color][textual.color.Color.rich_color] property.
+This module contains a powerful [Color][textual.color.Color] class which Textual uses to manipulate colors.
 
 ## Named colors
 
 The following named colors are used by the [parse][textual.color.Color.parse] method.
 
+
 ```{.rich columns="80" title="colors"}
 from textual._color_constants import COLOR_NAME_TO_RGB
 from textual.color import Color
@@ -28,8 +26,6 @@ for name, triplet in sorted(COLOR_NAME_TO_RGB.items()):
     )
 output = table
 ```
-
-
 """
 
 from __future__ import annotations
@@ -44,8 +40,7 @@ import rich.repr
 from rich.color import Color as RichColor
 from rich.color import ColorType
 from rich.color_triplet import ColorTriplet
-from rich.style import Style
-from rich.text import Text
+from typing_extensions import Final
 
 from textual.css.scalar import percentage_string_to_float
 from textual.css.tokenize import CLOSE_BRACE, COMMA, DECIMAL, OPEN_BRACE, PERCENT
@@ -58,14 +53,14 @@ _TRUECOLOR = ColorType.TRUECOLOR
 
 
 class HSL(NamedTuple):
-    """A color in HLS format."""
+    """A color in HLS (Hue, Saturation, Lightness) format."""
 
     h: float
-    """Hue"""
+    """Hue in range 0 to 1."""
     s: float
-    """Saturation"""
+    """Saturation in range 0 to 1."""
     l: float
-    """Lightness"""
+    """Lightness in range 0 to 1."""
 
     @property
     def css(self) -> str:
@@ -73,28 +68,32 @@ class HSL(NamedTuple):
         h, s, l = self
 
         def as_str(number: float) -> str:
+            """Format a float."""
             return f"{number:.1f}".rstrip("0").rstrip(".")
 
         return f"hsl({as_str(h*360)},{as_str(s*100)}%,{as_str(l*100)}%)"
 
 
 class HSV(NamedTuple):
-    """A color in HSV format."""
+    """A color in HSV (Hue, Saturation, Value) format."""
 
     h: float
-    """Hue"""
+    """Hue in range 0 to 1."""
     s: float
-    """Saturation"""
+    """Saturation in range 0 to 1"""
     v: float
-    """Value"""
+    """Value un range 0 to 1."""
 
 
 class Lab(NamedTuple):
     """A color in CIE-L*ab format."""
 
     L: float
+    """Lightness in range 0 to 100."""
     a: float
+    """A axis in range -127 to 128."""
     b: float
+    """B axis in range -127 to 128."""
 
 
 RE_COLOR = re.compile(
@@ -126,7 +125,7 @@ class ColorParseError(Exception):
 
     Args:
         message: The error message
-        suggested_color: A close color we can suggest. Defaults to None.
+        suggested_color: A close color we can suggest.
     """
 
     def __init__(self, message: str, suggested_color: str | None = None):
@@ -136,26 +135,47 @@ class ColorParseError(Exception):
 
 @rich.repr.auto
 class Color(NamedTuple):
-    """A class to represent a RGB color with an alpha component."""
+    """A class to represent a color.
+
+    Colors are stored as three values representing the degree of red, green, and blue in a color, and a
+    fourth "alpha" value which defines where the color lies on a gradient of opaque to transparent.
+
+    Example:
+        ```python
+        >>> from textual.color import Color
+        >>> color = Color.parse("red")
+        >>> color
+        Color(255, 0, 0)
+        >>> color.darken(0.5)
+        Color(98, 0, 0)
+        >>> color + Color.parse("green")
+        Color(0, 128, 0)
+        >>> color_with_alpha = Color(100, 50, 25, 0.5)
+        >>> color_with_alpha
+        Color(100, 50, 25, a=0.5)
+        >>> color + color_with_alpha
+        Color(177, 25, 12)
+        ```
+    """
 
     r: int
-    """Red component (0-255)"""
+    """Red component in range 0 to 255."""
     g: int
-    """Green component (0-255)"""
+    """Green component in range 0 to 255."""
     b: int
-    """Blue component (0-255)"""
+    """Blue component in range 0 to 255."""
     a: float = 1.0
-    """Alpha component (0-1)"""
+    """Alpha component in range 0 to 1."""
 
     @classmethod
     def from_rich_color(cls, rich_color: RichColor) -> Color:
         """Create a new color from Rich's Color class.
 
         Args:
-            rich_color: An instance of rich.color.Color.
+            rich_color: An instance of [Rich color][rich.color.Color].
 
         Returns:
-            A new Color.
+            A new Color instance.
         """
         r, g, b = rich_color.get_truecolor()
         return cls(r, g, b)
@@ -175,39 +195,24 @@ class Color(NamedTuple):
         r, g, b = hls_to_rgb(h, l, s)
         return cls(int(r * 255 + 0.5), int(g * 255 + 0.5), int(b * 255 + 0.5))
 
-    def __rich__(self) -> Text:
-        """A Rich method to show the color."""
-        return Text(
-            f" {self!r} ",
-            style=Style.from_color(
-                self.get_contrast_text().rich_color, self.rich_color
-            ),
-        )
-
     @property
     def inverse(self) -> Color:
-        """The inverse of this color."""
+        """The inverse of this color.
+
+        Returns:
+            Inverse color.
+        """
         r, g, b, a = self
         return Color(255 - r, 255 - g, 255 - b, a)
 
     @property
     def is_transparent(self) -> bool:
-        """Check if the color is transparent, i.e. has 0 alpha.
-
-        Returns:
-            True if transparent, otherwise False.
-
-        """
+        """Is the color transparent (i.e. has 0 alpha)?"""
         return self.a == 0
 
     @property
     def clamped(self) -> Color:
-        """Get a color with all components saturated to maximum and minimum values.
-
-        Returns:
-            A color object.
-
-        """
+        """A clamped color (this color with all values in expected range)."""
         r, g, b, a = self
         _clamp = clamp
         color = Color(
@@ -236,27 +241,24 @@ class Color(NamedTuple):
 
         Returns:
             Normalized components.
-
         """
         r, g, b, _a = self
         return (r / 255, g / 255, b / 255)
 
     @property
     def rgb(self) -> tuple[int, int, int]:
-        """Get just the red, green, and blue components.
-
-        Returns:
-            Color components
-        """
+        """The red, green, and blue color components as a tuple of ints."""
         r, g, b, _ = self
         return (r, g, b)
 
     @property
     def hsl(self) -> HSL:
-        """Get the color as HSL.
+        """This color in HSL format.
+
+        HSL color is an alternative way of representing a color, which can be used in certain color calculations.
 
         Returns:
-            Color in HSL format.
+            Color encoded in HSL format.
         """
         r, g, b = self.normalized
         h, l, s = rgb_to_hls(r, g, b)
@@ -264,11 +266,10 @@ class Color(NamedTuple):
 
     @property
     def brightness(self) -> float:
-        """Get the human perceptual brightness.
-
-        Returns:
-            Brightness value (0-1).
+        """The human perceptual brightness.
 
+        A value of 1 is returned for pure white, and 0 for pure black.
+        Other colors lie on a gradient between the two extremes.
         """
         r, g, b = self.normalized
         brightness = (299 * r + 587 * g + 114 * b) / 1000
@@ -278,9 +279,7 @@ class Color(NamedTuple):
     def hex(self) -> str:
         """The color in CSS hex form, with 6 digits for RGB, and 8 digits for RGBA.
 
-        Returns:
-            A CSS hex-style color, e.g. `"#46b3de"` or `"#3342457f"`
-
+        For example, `"#46b3de"` for an RGB color, or `"#3342457f"` for a color with alpha.
         """
         r, g, b, a = self.clamped
         return (
@@ -293,30 +292,26 @@ class Color(NamedTuple):
     def hex6(self) -> str:
         """The color in CSS hex form, with 6 digits for RGB. Alpha is ignored.
 
-        Returns:
-            A CSS hex-style color, e.g. "#46b3de"
-
+        For example, `"#46b3de"`.
         """
         r, g, b, _a = self.clamped
         return f"#{r:02X}{g:02X}{b:02X}"
 
     @property
     def css(self) -> str:
-        """The color in CSS rgb or rgba form.
-
-        Returns:
-            A CSS style color, e.g. `"rgb(10,20,30)"` or `"rgb(50,70,80,0.5)"`
+        """The color in CSS RGB or RGBA form.
 
+        For example, `"rgb(10,20,30)"` for an RGB color, or `"rgb(50,70,80,0.5)"` for an RGBA color.
         """
         r, g, b, a = self
         return f"rgb({r},{g},{b})" if a == 1 else f"rgba({r},{g},{b},{a})"
 
     @property
     def monochrome(self) -> Color:
-        """Get a monochrome version of this color.
+        """A monochrome version of this color.
 
         Returns:
-            A new monochrome color.
+            The monochrome (black and white) version of this color.
         """
         r, g, b, a = self
         gray = round(r * 0.2126 + g * 0.7152 + b * 0.0722)
@@ -327,7 +322,7 @@ class Color(NamedTuple):
         yield r
         yield g
         yield b
-        yield "a", a
+        yield "a", a, 1.0
 
     def with_alpha(self, alpha: float) -> Color:
         """Create a new color with the given alpha.
@@ -342,10 +337,10 @@ class Color(NamedTuple):
         return Color(r, g, b, alpha)
 
     def multiply_alpha(self, alpha: float) -> Color:
-        """Create a new color, multiplying the alpha with a new alpha.
+        """Create a new color, multiplying the alpha by a constant.
 
         Args:
-            alpha: The alpha value to multiple by.
+            alpha: A value to multiple the alpha by (expected to be in the range 0 to 1).
 
         Returns:
             A new color.
@@ -358,10 +353,14 @@ class Color(NamedTuple):
     ) -> Color:
         """Generate a new color between two colors.
 
+        This method calculates a new color on a gradient.
+        The position on the gradient is given by `factor`, which is a float between 0 and 1, where 0 is the original color, and 1 is the `destination` color.
+        A value of `gradient` between the two extremes produces a color somewhere between the two end points.
+
         Args:
             destination: Another color.
             factor: A blend factor, 0 -> 1.
-            alpha: New alpha for result. Defaults to None.
+            alpha: New alpha for result.
 
         Returns:
             A new color.
@@ -515,7 +514,7 @@ class Color(NamedTuple):
 
         Args:
             amount: Value between 0-1 to reduce luminance by.
-            alpha: Alpha component for new color or None to copy alpha. Defaults to None.
+            alpha: Alpha component for new color or None to copy alpha.
 
         Returns:
             New color.
@@ -529,7 +528,7 @@ class Color(NamedTuple):
 
         Args:
             amount: Value between 0-1 to increase luminance by.
-            alpha: Alpha component for new color or None to copy alpha. Defaults to None.
+            alpha: Alpha component for new color or None to copy alpha.
 
         Returns:
             New color.
@@ -541,8 +540,7 @@ class Color(NamedTuple):
         """Get a light or dark color that best contrasts this color, for use with text.
 
         Args:
-            alpha: An alpha value to adjust the pure white / black by.
-                Defaults to 0.95.
+            alpha: An alpha value to apply to the result.
 
         Returns:
             A new color, either an off-white or off-black
@@ -597,8 +595,10 @@ class Gradient:
 
 
 # Color constants
-WHITE = Color(255, 255, 255)
-BLACK = Color(0, 0, 0)
+WHITE: Final = Color(255, 255, 255)
+"""A constant for pure white."""
+BLACK: Final = Color(0, 0, 0)
+"""A constant for pure black."""
 
 
 def rgb_to_lab(rgb: Color) -> Lab:
