@@ -1,3 +1,10 @@
+"""
+
+A DOMNode is a base class for any object within the Textual Document Object Model,
+which includes all Widgets, Screens, and Apps.
+"""
+
+
 from __future__ import annotations
 
 import re
@@ -25,7 +32,7 @@ from ._context import NoActiveAppError
 from ._node_list import NodeList
 from ._types import WatchCallbackType
 from ._worker_manager import WorkerManager
-from .binding import Binding, Bindings, BindingType
+from .binding import Binding, BindingType, _Bindings
 from .color import BLACK, WHITE, Color
 from .css._error_tools import friendly_list
 from .css.constants import VALID_DISPLAY, VALID_VISIBILITY
@@ -39,6 +46,7 @@ from .timer import Timer
 from .walk import walk_breadth_first, walk_depth_first
 
 if TYPE_CHECKING:
+    from rich.console import RenderableType
     from .app import App
     from .css.query import DOMQuery, QueryType
     from .screen import Screen
@@ -55,7 +63,7 @@ WalkMethod: TypeAlias = Literal["depth", "breadth"]
 
 
 class BadIdentifier(Exception):
-    """raised by check_identifiers."""
+    """Exception raised if you supply a `id` attribute or class name in the wrong format."""
 
 
 def check_identifiers(description: str, *names: str) -> None:
@@ -63,10 +71,7 @@ def check_identifiers(description: str, *names: str) -> None:
 
     Args:
         description: Description of where identifier is used for error message.
-        names: Identifiers to check.
-
-    Returns:
-        True if the name is valid.
+        *names: Identifiers to check.
     """
     match = _re_identifier.match
     for name in names:
@@ -78,11 +83,11 @@ def check_identifiers(description: str, *names: str) -> None:
 
 
 class DOMError(Exception):
-    pass
+    """Base exception class for errors relating to the DOM."""
 
 
 class NoScreen(DOMError):
-    pass
+    """Raised when the node has no associated screen."""
 
 
 class _ClassesDescriptor:
@@ -134,7 +139,7 @@ class DOMNode(MessagePump):
     _css_type_names: ClassVar[frozenset[str]] = frozenset()
 
     # Generated list of bindings
-    _merged_bindings: ClassVar[Bindings | None] = None
+    _merged_bindings: ClassVar[_Bindings | None] = None
 
     _reactives: ClassVar[dict[str, Reactive]]
 
@@ -168,7 +173,7 @@ class DOMNode(MessagePump):
         self._auto_refresh_timer: Timer | None = None
         self._css_types = {cls.__name__ for cls in self._css_bases(self.__class__)}
         self._bindings = (
-            Bindings()
+            _Bindings()
             if self._merged_bindings is None
             else self._merged_bindings.copy()
         )
@@ -191,12 +196,16 @@ class DOMNode(MessagePump):
 
     @property
     def children(self) -> Sequence["Widget"]:
-        """A view on to the children."""
+        """A view on to the children.
+
+        Returns:
+            The node's children.
+        """
         return self._nodes
 
     @property
     def auto_refresh(self) -> float | None:
-        """Interval to refresh widget, or `None` for no automatic refresh."""
+        """Number of seconds between automatic refresh, or `None` for no automatic refresh."""
         return self._auto_refresh
 
     @auto_refresh.setter
@@ -212,7 +221,7 @@ class DOMNode(MessagePump):
 
     @property
     def workers(self) -> WorkerManager:
-        """A worker manager."""
+        """The app's worker manager. Shortcut for `self.app.workers`."""
         return self.app.workers
 
     def run_worker(
@@ -312,7 +321,10 @@ class DOMNode(MessagePump):
         Reactive._initialize_object(self)
 
     def notify_style_update(self) -> None:
-        """Called after styles are updated."""
+        """Called after styles are updated.
+
+        Implement this in a subclass if you want to clear any cached data when the CSS is reloaded.
+        """
 
     @property
     def _node_bases(self) -> Sequence[Type[DOMNode]]:
@@ -346,27 +358,27 @@ class DOMNode(MessagePump):
         return classes
 
     @classmethod
-    def _merge_bindings(cls) -> Bindings:
+    def _merge_bindings(cls) -> _Bindings:
         """Merge bindings from base classes.
 
         Returns:
             Merged bindings.
         """
-        bindings: list[Bindings] = []
+        bindings: list[_Bindings] = []
 
         for base in reversed(cls.__mro__):
             if issubclass(base, DOMNode):
                 if not base._inherit_bindings:
                     bindings.clear()
                 bindings.append(
-                    Bindings(
+                    _Bindings(
                         base.__dict__.get("BINDINGS", []),
                     )
                 )
         keys: dict[str, Binding] = {}
         for bindings_ in bindings:
             keys.update(bindings_.keys)
-        return Bindings(keys.values())
+        return _Bindings(keys.values())
 
     def _post_register(self, app: App) -> None:
         """Called when the widget is registered
@@ -430,15 +442,21 @@ class DOMNode(MessagePump):
 
     @property
     def parent(self) -> DOMNode | None:
-        """The parent node."""
+        """The parent node.
+
+        All nodes have parent once added to the DOM, with the exception of the App which is the *root* node.
+        """
         return cast("DOMNode | None", self._parent)
 
     @property
     def screen(self) -> "Screen":
-        """The screen that this node is contained within.
+        """The screen containing this node.
 
-        Note:
-            This may not be the currently active screen within the app.
+        Returns:
+            A screen object.
+
+        Raises:
+            NoScreen: If this node isn't mounted (and has no screen).
         """
         # Get the node by looking up a chain of parents
         # Note that self.screen may not be the same as self.app.screen
@@ -465,7 +483,6 @@ class DOMNode(MessagePump):
 
         Raises:
             ValueError: If the ID has already been set.
-
         """
         check_identifiers("id", new_id)
 
@@ -491,7 +508,11 @@ class DOMNode(MessagePump):
 
     @property
     def css_identifier_styled(self) -> Text:
-        """A stylized CSS identifier."""
+        """A syntax highlighted CSS identifier.
+
+        Returns:
+            A Rich Text object.
+        """
         tokens = Text.styled(self.__class__.__name__)
         if self.id is not None:
             tokens.append(f"#{self.id}", style="bold")
@@ -503,16 +524,21 @@ class DOMNode(MessagePump):
         return tokens
 
     classes = _ClassesDescriptor()
+    """CSS class names for this node."""
 
     @property
     def pseudo_classes(self) -> frozenset[str]:
-        """A set of all pseudo classes"""
-        pseudo_classes = frozenset({*self.get_pseudo_classes()})
+        """A (frozen) set of all pseudo classes."""
+        pseudo_classes = frozenset(self.get_pseudo_classes())
         return pseudo_classes
 
     @property
     def css_path_nodes(self) -> list[DOMNode]:
-        """A list of nodes from the root to this node, forming a "path"."""
+        """A list of nodes from the App to this node, forming a "path".
+
+        Returns:
+            A list of nodes, where the first item is the App, and the last is this node.
+        """
         result: list[DOMNode] = [self]
         append = result.append
 
@@ -541,7 +567,15 @@ class DOMNode(MessagePump):
 
     @property
     def display(self) -> bool:
-        """Should the DOM node be displayed?"""
+        """Should the DOM node be displayed?
+
+        May be set to a boolean to show or hide the node, or to any valid value for the `display` rule.
+
+        Example:
+            ```python
+            my_widget.display = False  # Hide my_widget
+            ```
+        """
         return self.styles.display != "none" and not (self._closing or self._closed)
 
     @display.setter
@@ -567,7 +601,12 @@ class DOMNode(MessagePump):
 
     @property
     def visible(self) -> bool:
-        """Is the visibility style set to a visible state?"""
+        """Is the visibility style set to a visible state?
+
+        May be set to a boolean to make the node visible (`True`) or invisible (`False`), or to any valid value for the `visibility` rule.
+
+        When a node is invisible, Textual will reserve space for it, but won't display anything there.
+        """
         return self.styles.visibility != "hidden"
 
     @visible.setter
@@ -584,9 +623,21 @@ class DOMNode(MessagePump):
 
     @property
     def tree(self) -> Tree:
-        """Get a Rich tree object which will recursively render the structure of the node tree."""
+        """A Rich tree to display the DOM.
+
+        Log this to visualize your app in the textual console.
+
+        Example:
+            ```python
+            self.log(self.tree)
+            ```
+
+        Returns:
+            A Tree renderable.
+        """
 
         def render_info(node: DOMNode) -> Pretty:
+            """Render a node for the tree."""
             return Pretty(node)
 
         tree = Tree(render_info(self))
@@ -603,8 +654,17 @@ class DOMNode(MessagePump):
 
     @property
     def css_tree(self) -> Tree:
-        """Get a Rich tree object which will recursively render the structure of the node tree,
-        which also displays CSS and size information.
+        """A Rich tree to display the DOM, annotated with the node's CSS.
+
+        Log this to visualize your app in the textual console.
+
+        Example:
+            ```python
+            self.log(self.css_tree)
+            ```
+
+        Returns:
+            A Tree renderable.
         """
         from rich.columns import Columns
         from rich.console import Group
@@ -613,6 +673,7 @@ class DOMNode(MessagePump):
         from .widget import Widget
 
         def render_info(node: DOMNode) -> Columns:
+            """Render a node for the tree."""
             if isinstance(node, Widget):
                 info = Columns(
                     [
@@ -630,9 +691,10 @@ class DOMNode(MessagePump):
         highlighter = ReprHighlighter()
         tree = Tree(render_info(self))
 
-        def add_children(tree, node):
+        def add_children(tree: Tree, node: DOMNode) -> None:
+            """Add children to the tree."""
             for child in node.children:
-                info = render_info(child)
+                info: RenderableType = render_info(child)
                 css = child.styles.css
                 if css:
                     info = Group(
@@ -659,7 +721,7 @@ class DOMNode(MessagePump):
         the child will also be bold.
 
         Returns:
-            Rich Style object.
+            A Rich Style.
         """
         return Style.combine(
             node.styles.text_style for node in reversed(self.ancestors_with_self)
@@ -667,7 +729,11 @@ class DOMNode(MessagePump):
 
     @property
     def rich_style(self) -> Style:
-        """Get a Rich Style object for this DOMNode."""
+        """Get a Rich Style object for this DOMNode.
+
+        Returns:
+            A Rich style.
+        """
         background = Color(0, 0, 0, 0)
         color = Color(255, 255, 255, 0)
         style = Style()
@@ -686,9 +752,57 @@ class DOMNode(MessagePump):
         )
         return style
 
+    def _get_title_style_information(
+        self, background: Color
+    ) -> tuple[Color, Color, Style]:
+        """Get a Rich Style object for for titles.
+
+        Args:
+            background: The background color.
+
+        Returns:
+            A Rich style.
+        """
+        styles = self.styles
+        if styles.auto_border_title_color:
+            color = background.get_contrast_text(styles.border_title_color.a)
+        else:
+            color = styles.border_title_color
+        return (
+            color,
+            styles.border_title_background,
+            styles.border_title_style,
+        )
+
+    def _get_subtitle_style_information(
+        self, background: Color
+    ) -> tuple[Color, Color, Style]:
+        """Get a Rich Style object for for titles.
+
+        Args:
+            background: The background color.
+
+        Returns:
+            A Rich style.
+        """
+        styles = self.styles
+        if styles.auto_border_subtitle_color:
+            color = background.get_contrast_text(styles.border_subtitle_color.a)
+        else:
+            color = styles.border_subtitle_color
+        return (
+            color,
+            styles.border_subtitle_background,
+            styles.border_subtitle_style,
+        )
+
     @property
     def background_colors(self) -> tuple[Color, Color]:
-        """The background color and the color of the parent's background."""
+        """The background color and the color of the parent's background.
+
+        Returns:
+            `(<background color>, <color>)`
+        """
         base_background = background = BLACK
         for node in reversed(self.ancestors_with_self):
             styles = node.styles
@@ -698,7 +812,11 @@ class DOMNode(MessagePump):
 
     @property
     def colors(self) -> tuple[Color, Color, Color, Color]:
-        """The widget's foreground and background colors, and its parent's (base) colors."""
+        """The widget's background and foreground colors, and the parent's background and foreground colors.
+
+        Returns:
+            `(<parent background>, <parent color>, <background>, <color>)`
+        """
         base_background = background = WHITE
         base_color = color = BLACK
         for node in reversed(self.ancestors_with_self):
@@ -720,6 +838,9 @@ class DOMNode(MessagePump):
 
         Note:
             This is inclusive of ``self``.
+
+        Returns:
+            A list of nodes.
         """
         nodes: list[MessagePump | None] = []
         add_node = nodes.append
@@ -731,12 +852,20 @@ class DOMNode(MessagePump):
 
     @property
     def ancestors(self) -> list[DOMNode]:
-        """A list of ancestor nodes Nodes by tracing ancestors all the way back to App."""
+        """A list of ancestor nodes Nodes by tracing ancestors all the way back to App.
+
+        Returns:
+            A list of nodes.
+        """
         return self.ancestors_with_self[1:]
 
     @property
     def displayed_children(self) -> list[Widget]:
-        """The children which don't have display: none set."""
+        """The child nodes which will be displayed.
+
+        Returns:
+            A list of nodes.
+        """
         return [child for child in self._nodes if child.display]
 
     def watch(
@@ -748,6 +877,18 @@ class DOMNode(MessagePump):
     ) -> None:
         """Watches for modifications to reactive attributes on another object.
 
+        Example:
+
+            Here's how you could detect when the app changes from dark to light mode (and visa versa).
+
+            ```python
+            def on_dark_change(old_value:bool, new_value:bool):
+                # Called when app.dark changes.
+                print("App.dark when from {old_value} to {new_value}")
+
+            self.watch(self.app, "dark", self.on_dark_change, init=False)
+            ```
+
         Args:
             obj: Object containing attribute to watch.
             attribute_name: Attribute to watch.
@@ -765,7 +906,7 @@ class DOMNode(MessagePump):
         return ()
 
     def reset_styles(self) -> None:
-        """Reset styles back to their initial state"""
+        """Reset styles back to their initial state."""
         from .widget import Widget
 
         for node in self.walk_children(with_self=True):
@@ -829,14 +970,12 @@ class DOMNode(MessagePump):
 
         Args:
             filter_type: Filter only this type, or None for no filter.
-                Defaults to None.
-            with_self: Also yield self in addition to descendants. Defaults to False.
-            method: One of "depth" or "breadth". Defaults to "depth".
-            reverse: Reverse the order (bottom up). Defaults to False.
+            with_self: Also yield self in addition to descendants.
+            method: One of "depth" or "breadth".
+            reverse: Reverse the order (bottom up).
 
         Returns:
             A list of nodes.
-
         """
         check_type = filter_type or DOMNode
 
@@ -867,7 +1006,7 @@ class DOMNode(MessagePump):
         """Get a DOM query matching a selector.
 
         Args:
-            selector: A CSS selector or `None` for all nodes. Defaults to None.
+            selector: A CSS selector or `None` for all nodes.
 
         Returns:
             A query object.
@@ -902,7 +1041,6 @@ class DOMNode(MessagePump):
         Args:
             selector: A selector.
             expect_type: Require the object be of the supplied type, or None for any type.
-                Defaults to None.
 
         Raises:
             WrongType: If the wrong type was found.
