@@ -9,46 +9,48 @@ import termios
 import tty
 from codecs import getincrementaldecoder
 from threading import Event, Thread
-from typing import IO, Any
+from typing import TYPE_CHECKING, Any
 
 import rich.repr
 
 from .. import events, log
-from .._types import MessageTarget
 from .._xterm_parser import XTermParser
 from ..driver import Driver
 from ..geometry import Size
+from ._writer_thread import WriterThread
+
+if TYPE_CHECKING:
+    from ..app import App
 
 
-@rich.repr.auto
+@rich.repr.auto(angular=True)
 class LinuxDriver(Driver):
     """Powers display and input for Linux / MacOS"""
 
     def __init__(
         self,
-        file: IO[str],
-        target: "MessageTarget",
+        app: App,
         *,
         debug: bool = False,
         size: tuple[int, int] | None = None,
     ) -> None:
-        """Initialize a driver.
+        """Initialize Linux driver.
 
         Args:
-            file: A file-like object open for writing unicode.
-            target: The message target (expected to be the app).
-            debug: Enabled debug mode.
+            app: The App instance.
+            debug: Enable debug mode.
             size: Initial size of the terminal or `None` to detect.
         """
-        super().__init__(file, target, debug=debug, size=size)
-        self._file = file
+        super().__init__(app, debug=debug, size=size)
+        self._file = sys.__stdout__
         self.fileno = sys.stdin.fileno()
         self.attrs_before: list[Any] | None = None
         self.exit_event = Event()
         self._key_thread: Thread | None = None
+        self._writer_thread: WriterThread | None = None
 
     def __rich_repr__(self) -> rich.repr.Result:
-        yield "debug", self._debug
+        yield self._app
 
     def _get_terminal_size(self) -> tuple[int, int]:
         """Detect the terminal size.
@@ -108,7 +110,8 @@ class LinuxDriver(Driver):
         Args:
             data: Raw data.
         """
-        self._file.write(data)
+        assert self._writer_thread is not None, "Driver must be in application mode"
+        self._writer_thread.write(data)
 
     def start_application_mode(self):
         """Start application mode."""
@@ -120,10 +123,13 @@ class LinuxDriver(Driver):
             textual_size = Size(width, height)
             event = events.Resize(textual_size, textual_size)
             asyncio.run_coroutine_threadsafe(
-                self._target._post_message(event),
+                self._app._post_message(event),
                 loop=loop,
             )
 
+        self._writer_thread = WriterThread(self._file)
+        self._writer_thread.start()
+
         def on_terminal_resize(signum, stack) -> None:
             send_size_event()
 
@@ -222,6 +228,11 @@ class LinuxDriver(Driver):
             self.write("\x1b[?1049l" + "\x1b[?25h")
             self.flush()
 
+    def close(self) -> None:
+        """Perform cleanup."""
+        if self._writer_thread is not None:
+            self._writer_thread.stop()
+
     def run_input_thread(self) -> None:
         """Wait for input and dispatch events."""
         selector = selectors.DefaultSelector()
