@@ -1,13 +1,16 @@
 from __future__ import annotations
 
 import asyncio
+import sys
 from threading import Event, Thread
-from typing import IO, Callable
+from typing import TYPE_CHECKING, Callable
 
-from .._context import active_app
-from .._types import MessageTarget
 from ..driver import Driver
 from . import win32
+from ._writer_thread import WriterThread
+
+if TYPE_CHECKING:
+    from ..app import App
 
 
 class WindowsDriver(Driver):
@@ -15,25 +18,24 @@ class WindowsDriver(Driver):
 
     def __init__(
         self,
-        file: IO[str],
-        target: "MessageTarget",
+        app: App,
         *,
         debug: bool = False,
         size: tuple[int, int] | None = None,
     ) -> None:
-        """Initialize a driver.
+        """Initialize Windows driver.
 
         Args:
-            file: A file-like object open for writing unicode.
-            target: The message target (expected to be the app).
-            debug: Enabled debug mode.
+            app: The App instance.
+            debug: Enable debug mode.
             size: Initial size of the terminal or `None` to detect.
         """
-        super().__init__(file, target, debug=debug, size=size)
-
+        super().__init__(app, debug=debug, size=size)
+        self._file = sys.__stdout__
         self.exit_event = Event()
         self._event_thread: Thread | None = None
         self._restore_console: Callable[[], None] | None = None
+        self._writer_thread: WriterThread | None = None
 
     def write(self, data: str) -> None:
         """Write data to the output device.
@@ -41,7 +43,8 @@ class WindowsDriver(Driver):
         Args:
             data: Raw data.
         """
-        self._file.write(data)
+        assert self._writer_thread is not None, "Driver must be in application mode"
+        self._writer_thread.write(data)
 
     def _enable_mouse_support(self) -> None:
         """Enable reporting of mouse events."""
@@ -73,6 +76,9 @@ class WindowsDriver(Driver):
         """Start application mode."""
         loop = asyncio.get_running_loop()
 
+        self._writer_thread = WriterThread(self._file)
+        self._writer_thread.start()
+
         self._restore_console = win32.enable_application_mode()
 
         self.write("\x1b[?1049h")  # Enable alt screen
@@ -81,10 +87,8 @@ class WindowsDriver(Driver):
         self.write("\033[?1003h\n")
         self._enable_bracketed_paste()
 
-        app = active_app.get()
-
         self._event_thread = win32.EventMonitor(
-            loop, app, self._target, self.exit_event, self.process_event
+            loop, self._app, self.exit_event, self.process_event
         )
         self._event_thread.start()
 
@@ -112,3 +116,8 @@ class WindowsDriver(Driver):
         # Disable alt screen, show cursor
         self.write("\x1b[?1049l" + "\x1b[?25h")
         self.flush()
+
+    def close(self) -> None:
+        """Perform cleanup."""
+        if self._writer_thread is not None:
+            self._writer_thread.stop()
