@@ -1,9 +1,6 @@
 """
 
-A message pump is a class that processes messages.
-
-It is a base class for the App, Screen, and Widgets.
-
+A message pump is a base class for any object which processes messages, which includes Widget, Screen, and App.
 """
 from __future__ import annotations
 
@@ -46,10 +43,9 @@ class MessagePumpClosed(Exception):
     pass
 
 
-class MessagePumpMeta(type):
+class _MessagePumpMeta(type):
     """Metaclass for message pump. This exists to populate a Message inner class of a Widget with the
     parent classes' name.
-
     """
 
     def __new__(
@@ -69,7 +65,7 @@ class MessagePumpMeta(type):
         return class_obj
 
 
-class MessagePump(metaclass=MessagePumpMeta):
+class MessagePump(metaclass=_MessagePumpMeta):
     """Base class which supplies a message pump."""
 
     def __init__(self, parent: MessagePump | None = None) -> None:
@@ -124,7 +120,6 @@ class MessagePump(metaclass=MessagePumpMeta):
             with self.prevent(Input.Changed):
                 input.value = "foo"
             ```
-
         """
         if message_types:
             prevent_stack = self._prevent_message_types_stack
@@ -143,6 +138,7 @@ class MessagePump(metaclass=MessagePumpMeta):
 
     @property
     def has_parent(self) -> bool:
+        """Does this object have a parent?"""
         return self._parent is not None
 
     @property
@@ -178,7 +174,7 @@ class MessagePump(metaclass=MessagePumpMeta):
 
     @property
     def is_running(self) -> bool:
-        """Is the message pump running (potentially processing messages)."""
+        """Is the message pump running (potentially processing messages)?"""
         return self._running
 
     @property
@@ -192,7 +188,7 @@ class MessagePump(metaclass=MessagePumpMeta):
 
     @property
     def is_attached(self) -> bool:
-        """Is the node is attached to the app via the DOM."""
+        """Is the node is attached to the app via the DOM?"""
         from .app import App
 
         node = self
@@ -289,9 +285,9 @@ class MessagePump(metaclass=MessagePumpMeta):
 
         Args:
             delay: Time to wait before invoking callback.
-            callback: Callback to call after time has expired. Defaults to None.
-            name: Name of the timer (for debug). Defaults to None.
-            pause: Start timer paused. Defaults to False.
+            callback: Callback to call after time has expired.
+            name: Name of the timer (for debug).
+            pause: Start timer paused.
 
         Returns:
             A timer object.
@@ -304,7 +300,7 @@ class MessagePump(metaclass=MessagePumpMeta):
             repeat=0,
             pause=pause,
         )
-        timer.start()
+        timer._start()
         self._timers.add(timer)
         return timer
 
@@ -321,10 +317,10 @@ class MessagePump(metaclass=MessagePumpMeta):
 
         Args:
             interval: Time between calls.
-            callback: Function to call. Defaults to None.
-            name: Name of the timer object. Defaults to None.
-            repeat: Number of times to repeat the call or 0 for continuous. Defaults to 0.
-            pause: Start the timer paused. Defaults to False.
+            callback: Function to call.
+            name: Name of the timer object.
+            repeat: Number of times to repeat the call or 0 for continuous.
+            pause: Start the timer paused.
 
         Returns:
             A timer object.
@@ -337,7 +333,7 @@ class MessagePump(metaclass=MessagePumpMeta):
             repeat=repeat or None,
             pause=pause,
         )
-        timer.start()
+        timer._start()
         self._timers.add(timer)
         return timer
 
@@ -375,6 +371,7 @@ class MessagePump(metaclass=MessagePumpMeta):
             **kwargs: Keyword arguments to pass to the callable.
         """
         self._next_callbacks.append(partial(callback, *args, **kwargs))
+        self.check_idle()
 
     def _on_invoke_later(self, message: messages.InvokeLater) -> None:
         # Forward InvokeLater message to the Screen
@@ -507,6 +504,7 @@ class MessagePump(metaclass=MessagePumpMeta):
                             except Exception as error:
                                 self.app._handle_exception(error)
                                 break
+                    await self._flush_next_callbacks()
 
     async def _flush_next_callbacks(self) -> None:
         """Invoke pending callbacks in next callbacks queue."""
@@ -546,7 +544,6 @@ class MessagePump(metaclass=MessagePumpMeta):
         Args:
             method_name: Handler method name.
             message: Message object.
-
         """
         private_method = f"_{method_name}"
         for cls in self.__class__.__mro__:
@@ -615,13 +612,13 @@ class MessagePump(metaclass=MessagePumpMeta):
         return self.post_message(message)
 
     def post_message(self, message: Message) -> bool:
-        """Posts a message on the queue.
+        """Posts a message on to this widget's queue.
 
         Args:
-            message: A message (or Event).
+            message: A message (including Event).
 
         Returns:
-            True if the messages was processed, False if it wasn't.
+            `True` if the messages was processed, `False` if it wasn't.
         """
         if self._closing or self._closed:
             return False
