@@ -1,3 +1,8 @@
+"""
+
+The pilot object is used by [App.run_test][textual.app.App.run_test] to programmatically operate an app.
+"""
+
 from __future__ import annotations
 
 import asyncio
@@ -57,7 +62,6 @@ class Pilot(Generic[ReturnType]):
 
         Args:
             *keys: Keys to press.
-
         """
         if keys:
             await self._app._press_keys(keys)
@@ -94,11 +98,11 @@ class Pilot(Generic[ReturnType]):
             target_widget, offset, button=1, shift=shift, meta=meta, control=control
         )
         app.post_message(MouseDown(**message_arguments))
-        await self.pause()
+        await self.pause(0.1)
         app.post_message(MouseUp(**message_arguments))
-        await self.pause()
+        await self.pause(0.1)
         app.post_message(Click(**message_arguments))
-        await self.pause()
+        await self.pause(0.1)
 
     async def hover(
         self,
@@ -139,15 +143,18 @@ class Pilot(Generic[ReturnType]):
             await wait_for_idle(0)
         else:
             await asyncio.sleep(delay)
+        self.app.screen._on_timer_update()
 
     async def wait_for_animation(self) -> None:
         """Wait for any current animation to complete."""
         await self._app.animator.wait_for_idle()
+        self.app.screen._on_timer_update()
 
     async def wait_for_scheduled_animations(self) -> None:
         """Wait for any current and scheduled animations to complete."""
         await self._app.animator.wait_until_complete()
         await wait_for_idle()
+        self.app.screen._on_timer_update()
 
     async def exit(self, result: ReturnType) -> None:
         """Exit the app with the given result.
