@@ -1,6 +1,22 @@
+"""
+
+The `Screen` class is a special widget which represents the content in the terminal. See [Screens](/guide/screens/) for details.
+"""
+
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Iterable, Iterator
+from typing import (
+    TYPE_CHECKING,
+    Awaitable,
+    Callable,
+    Generic,
+    Iterable,
+    Iterator,
+    Type,
+    TypeVar,
+    Union,
+    cast,
+)
 
 import rich.repr
 from rich.console import RenderableType
@@ -25,13 +41,53 @@ from .widget import Widget
 if TYPE_CHECKING:
     from typing_extensions import Final
 
-# Screen updates will be batched so that they don't happen more often than 120 times per second:
-UPDATE_PERIOD: Final[float] = 1 / 120
+# Screen updates will be batched so that they don't happen more often than 60 times per second:
+UPDATE_PERIOD: Final[float] = 1 / 60
+
+ScreenResultType = TypeVar("ScreenResultType")
+"""The result type of a screen."""
+
+ScreenResultCallbackType = Union[
+    Callable[[ScreenResultType], None], Callable[[ScreenResultType], Awaitable[None]]
+]
+"""Type of a screen result callback function."""
+
+
+class ResultCallback(Generic[ScreenResultType]):
+    """Holds the details of a callback."""
+
+    def __init__(
+        self,
+        requester: Widget | None,
+        callback: ScreenResultCallbackType[ScreenResultType] | None,
+    ) -> None:
+        """Initialise the result callback object.
+
+        Args:
+            requester: The object making a request for the callback.
+            callback: The callback function.
+        """
+        self.requester: Widget | None = requester
+        """The object in the DOM that requested the callback."""
+        self.callback: ScreenResultCallbackType | None = callback
+        """The callback function."""
+
+    def __call__(self, result: ScreenResultType) -> None:
+        """Call the callback, passing the given result.
+
+        Args:
+            result: The result to pass to the callback.
+
+        Note:
+            If the requested or the callback are `None` this will be a no-op.
+        """
+        if self.requester is not None and self.callback is not None:
+            self.requester.call_next(self.callback, result)
 
 
 @rich.repr.auto
-class Screen(Widget):
-    """A widget for the root of the app."""
+class Screen(Generic[ScreenResultType], Widget):
+    """The base class for screens."""
 
     DEFAULT_CSS = """
     Screen {
@@ -42,7 +98,7 @@ class Screen(Widget):
     """
 
     focused: Reactive[Widget | None] = Reactive(None)
-    """The focused widget or `None` for no focus."""
+    """The focused [widget][textual.widget.Widget] or `None` for no focus."""
     stack_updates: Reactive[int] = Reactive(0, repaint=False)
     """An integer that updates when the screen is resumed."""
 
@@ -57,12 +113,21 @@ class Screen(Widget):
         id: str | None = None,
         classes: str | None = None,
     ) -> None:
+        """
+        Initialize the screen.
+
+        Args:
+            name: The name of the screen.
+            id: The ID of the screen in the DOM.
+            classes: The CSS classes for the screen.
+        """
         self._modal = False
         super().__init__(name=name, id=id, classes=classes)
         self._compositor = Compositor()
         self._dirty_widgets: set[Widget] = set()
-        self._update_timer: Timer | None = None
+        self.__update_timer: Timer | None = None
         self._callbacks: list[CallbackType] = []
+        self._result_callbacks: list[ResultCallback[ScreenResultType]] = []
 
     @property
     def is_modal(self) -> bool:
@@ -84,13 +149,13 @@ class Screen(Widget):
             return False
 
     @property
-    def update_timer(self) -> Timer:
+    def _update_timer(self) -> Timer:
         """Timer used to perform updates."""
-        if self._update_timer is None:
-            self._update_timer = self.set_interval(
+        if self.__update_timer is None:
+            self.__update_timer = self.set_interval(
                 UPDATE_PERIOD, self._on_timer_update, name="screen_update", pause=True
             )
-        return self._update_timer
+        return self.__update_timer
 
     def render(self) -> RenderableType:
         background = self.styles.background
@@ -371,55 +436,50 @@ class Screen(Widget):
         event.prevent_default()
 
         if not self.app._batch_count and self.is_current:
-            async with self.app._dom_lock:
-                if self.is_current:
-                    if self._layout_required:
-                        self._refresh_layout()
-                        self._layout_required = False
-                        self._scroll_required = False
-                        self._dirty_widgets.clear()
-                    elif self._scroll_required:
-                        self._refresh_layout(scroll=True)
-                        self._scroll_required = False
+            if (
+                self._layout_required
+                or self._scroll_required
+                or self._repaint_required
+                or self._dirty_widgets
+            ):
+                self._update_timer.resume()
+                return
 
-                    if self._repaint_required:
-                        self._dirty_widgets.clear()
-                        self._dirty_widgets.add(self)
-                        self._repaint_required = False
-
-                    if self._dirty_widgets:
-                        self.update_timer.resume()
-
-        # The Screen is idle - a good opportunity to invoke the scheduled callbacks
         await self._invoke_and_clear_callbacks()
 
     def _on_timer_update(self) -> None:
         """Called by the _update_timer."""
-        # Render widgets together
-        if self._dirty_widgets and self.is_current:
-            self._compositor.update_widgets(self._dirty_widgets)
-            update = self._compositor.render_update(
-                screen_stack=self.app._background_screens
-            )
-            self.app._display(self, update)
-            self._dirty_widgets.clear()
+        self._update_timer.pause()
+        if self.is_current:
+            if self._layout_required:
+                self._refresh_layout()
+                self._layout_required = False
+                self._scroll_required = False
+                self._dirty_widgets.clear()
+            elif self._scroll_required:
+                self._refresh_layout(scroll=True)
+                self._scroll_required = False
+
+            if self._repaint_required:
+                self._dirty_widgets.clear()
+                self._dirty_widgets.add(self)
+                self._repaint_required = False
+
+            if self._dirty_widgets:
+                self._compositor.update_widgets(self._dirty_widgets)
+                update = self._compositor.render_update(
+                    screen_stack=self.app._background_screens
+                )
+                self.app._display(self, update)
+                self._dirty_widgets.clear()
+
         if self._callbacks:
-            self.post_message(events.InvokeCallbacks())
-
-        self.update_timer.pause()
-
-    async def _on_invoke_callbacks(self, event: events.InvokeCallbacks) -> None:
-        """Handle PostScreenUpdate events, which are sent after the screen is updated"""
-        await self._invoke_and_clear_callbacks()
+            self.call_next(self._invoke_and_clear_callbacks)
 
     async def _invoke_and_clear_callbacks(self) -> None:
         """If there are scheduled callbacks to run, call them and clear
         the callback queue."""
         if self._callbacks:
-            display_update = self._compositor.render_update(
-                screen_stack=self.app._background_screens
-            )
-            self.app._display(self, display_update)
             callbacks = self._callbacks[:]
             self._callbacks.clear()
             for callback in callbacks:
@@ -435,6 +495,25 @@ class Screen(Widget):
         self._callbacks.append(callback)
         self.check_idle()
 
+    def _push_result_callback(
+        self,
+        requester: Widget | None,
+        callback: ScreenResultCallbackType[ScreenResultType] | None,
+    ) -> None:
+        """Add a result callback to the screen.
+
+        Args:
+            requester: The object requesting the callback.
+            callback: The callback.
+        """
+        self._result_callbacks.append(
+            ResultCallback[ScreenResultType](requester, callback)
+        )
+
+    def _pop_result_callback(self) -> None:
+        """Remove the latest result callback from the stack."""
+        self._result_callbacks.pop()
+
     def _refresh_layout(
         self, size: Size | None = None, full: bool = False, scroll: bool = False
     ) -> None:
@@ -443,7 +522,7 @@ class Screen(Widget):
         if not size:
             return
         self._compositor.update_widgets(self._dirty_widgets)
-        self.update_timer.pause()
+        self._update_timer.pause()
         ResizeEvent = events.Resize
 
         try:
@@ -629,10 +708,43 @@ class Screen(Widget):
         else:
             self.post_message(event)
 
+    class _NoResult:
+        """Class used to mark that there is no result."""
+
+    def dismiss(self, result: ScreenResultType | Type[_NoResult] = _NoResult) -> None:
+        """Dismiss the screen, optionally with a result.
+
+        Args:
+            result: The optional result to be passed to the result callback.
+
+        Note:
+            If the screen was pushed with a callback, the callback will be
+            called with the given result and then a call to
+            [`App.pop_screen`][textual.app.App.pop_screen] is performed. If
+            no callback was provided calling this method is the same as
+            simply calling [`App.pop_screen`][textual.app.App.pop_screen].
+        """
+        if result is not self._NoResult and self._result_callbacks:
+            self._result_callbacks[-1](cast(ScreenResultType, result))
+        self.app.pop_screen()
+
+    def action_dismiss(
+        self, result: ScreenResultType | Type[_NoResult] = _NoResult
+    ) -> None:
+        """A wrapper around [`dismiss`][textual.screen.Screen.dismiss] that can be called as an action.
+
+        Args:
+            result: The optional result to be passed to the result callback.
+        """
+        self.dismiss(result)
+
 
 @rich.repr.auto
-class ModalScreen(Screen):
-    """A screen with bindings that take precedence over the App's key bindings."""
+class ModalScreen(Screen[ScreenResultType]):
+    """A screen with bindings that take precedence over the App's key bindings.
+
+    The default styling of a modal screen will dim the screen underneath.
+    """
 
     DEFAULT_CSS = """
     ModalScreen {
