@@ -2,7 +2,6 @@
 
 Timer objects are created by [set_interval][textual.message_pump.MessagePump.set_interval] or
     [set_timer][textual.message_pump.MessagePump.set_timer].
-
 """
 
 from __future__ import annotations
@@ -34,11 +33,11 @@ class Timer:
     Args:
         event_target: The object which will receive the timer events.
         interval: The time between timer events, in seconds.
-        name: A name to assign the event (for debugging). Defaults to None.
-        callback: A optional callback to invoke when the event is handled. Defaults to None.
-        repeat: The number of times to repeat the timer, or None to repeat forever. Defaults to None.
-        skip: Enable skipping of scheduled events that couldn't be sent in time. Defaults to True.
-        pause: Start the timer paused. Defaults to False.
+        name: A name to assign the event (for debugging).
+        callback: A optional callback to invoke when the event is handled.
+        repeat: The number of times to repeat the timer, or None to repeat forever.
+        skip: Enable skipping of scheduled events that couldn't be sent in time.
+        pause: Start the timer paused.
     """
 
     _timer_count: int = 1
@@ -80,14 +79,9 @@ class Timer:
             raise EventTargetGone()
         return target
 
-    def start(self) -> Task:
-        """Start the timer return the task.
-
-        Returns:
-            A Task instance for the timer.
-        """
+    def _start(self) -> None:
+        """Start the timer."""
         self._task = create_task(self._run_timer(), name=self.name)
-        return self._task
 
     def stop(self) -> None:
         """Stop the timer."""
@@ -100,7 +94,6 @@ class Timer:
         """Pause the timer.
 
         A paused timer will not send events until it is resumed.
-
         """
         self._active.clear()
 
@@ -136,9 +129,7 @@ class Timer:
                 continue
             now = _time.get_time()
             wait_time = max(0, next_timer - now)
-            if wait_time > 1 / 1000:
-                await sleep(wait_time)
-
+            await sleep(wait_time)
             count += 1
             await self._active.wait()
             if self._reset:
