@@ -3,11 +3,12 @@ from __future__ import annotations
 import os
 from dataclasses import dataclass
 from pathlib import Path
-from typing import ClassVar
+from typing import ClassVar, Iterable
 
 from rich.style import Style
 from rich.text import Text, TextType
 
+from ..events import Mount
 from ..message import Message
 from ._tree import TOGGLE_STYLE, Tree, TreeNode
 
@@ -149,12 +150,27 @@ class DirectoryTree(Tree[DirEntry]):
         text = Text.assemble(prefix, node_label)
         return text
 
+    def filter_paths(self, paths: Iterable[Path]) -> Iterable[Path]:
+        """Filter the paths before adding them to the tree.
+
+        Args:
+            paths: The paths to be filtered.
+
+        Returns:
+            The filtered paths.
+
+        By default this method returns all of the paths provided. To create
+        a filtered `DirectoryTree` inherit from it and implement your own
+        version of this method.
+        """
+        return paths
+
     def load_directory(self, node: TreeNode[DirEntry]) -> None:
         assert node.data is not None
         dir_path = Path(node.data.path)
         node.data.loaded = True
         directory = sorted(
-            list(dir_path.iterdir()),
+            self.filter_paths(dir_path.iterdir()),
             key=lambda path: (not path.is_dir(), path.name.lower()),
         )
         for path in directory:
@@ -165,10 +181,10 @@ class DirectoryTree(Tree[DirEntry]):
             )
         node.expand()
 
-    def on_mount(self) -> None:
+    def _on_mount(self, _: Mount) -> None:
         self.load_directory(self.root)
 
-    def on_tree_node_expanded(self, event: Tree.NodeSelected) -> None:
+    def _on_tree_node_expanded(self, event: Tree.NodeSelected) -> None:
         event.stop()
         dir_entry = event.node.data
         if dir_entry is None:
@@ -179,7 +195,7 @@ class DirectoryTree(Tree[DirEntry]):
         else:
             self.post_message(self.FileSelected(dir_entry.path))
 
-    def on_tree_node_selected(self, event: Tree.NodeSelected) -> None:
+    def _on_tree_node_selected(self, event: Tree.NodeSelected) -> None:
         event.stop()
         dir_entry = event.node.data
         if dir_entry is None:
