@@ -13,6 +13,7 @@ from typing_extensions import TypeAlias
 
 from ..app import ComposeResult
 from ..containers import Horizontal, VerticalScroll
+from ..events import Mount
 from ..message import Message
 from ..reactive import reactive, var
 from ..widget import Widget
@@ -129,7 +130,6 @@ class MarkdownH1(MarkdownHeader):
         text-style: bold;
         color: $text;
     }
-
     """
 
 
@@ -147,7 +147,6 @@ class MarkdownH2(MarkdownHeader):
         padding: 1;
         text-style: bold;
     }
-
     """
 
 
@@ -377,7 +376,6 @@ class MarkdownTable(MarkdownBlock):
         background: $panel;
         border: wide $background;
     }
-
     """
 
     def compose(self) -> ComposeResult:
@@ -478,6 +476,7 @@ class MarkdownFence(MarkdownBlock):
         width: 100%;
         height: auto;
         max-height: 20;
+        color: rgb(210,210,210);
     }
 
     MarkdownFence > * {
@@ -553,7 +552,7 @@ class Markdown(Widget):
         """A Markdown widget.
 
         Args:
-            markdown: String containing Markdown or None to leave blank for now. Defaults to None.
+            markdown: String containing Markdown or None to leave blank for now.
             name: The name of the widget.
             id: The ID of the widget in the DOM.
             classes: The CSS classes of the widget.
@@ -587,7 +586,7 @@ class Markdown(Widget):
             self.href: str = href
             """The link that was selected."""
 
-    def on_mount(self) -> None:
+    def _on_mount(self, _: Mount) -> None:
         if self._markdown is not None:
             self.update(self._markdown)
 
@@ -778,11 +777,11 @@ class MarkdownTableOfContents(Widget, can_focus_children=True):
         yield tree
 
     def watch_table_of_contents(self, table_of_contents: TableOfContentsType) -> None:
-        """Triggered when the TOC changes."""
+        """Triggered when the table of contents changes."""
         self.set_table_of_contents(table_of_contents)
 
     def set_table_of_contents(self, table_of_contents: TableOfContentsType) -> None:
-        """Set the Table of Contents.
+        """Set the table of contents.
 
         Args:
             table_of_contents: Table of contents.
@@ -801,7 +800,7 @@ class MarkdownTableOfContents(Widget, can_focus_children=True):
                     node = node.add(NUMERALS[level], expand=True)
             node.add_leaf(f"[dim]{NUMERALS[level]}[/] {name}", {"block_id": block_id})
 
-    async def on_tree_node_selected(self, message: Tree.NodeSelected) -> None:
+    async def _on_tree_node_selected(self, message: Tree.NodeSelected) -> None:
         node_data = message.node.data
         if node_data is not None:
             await self._post_message(
@@ -829,7 +828,6 @@ class MarkdownViewer(VerticalScroll, can_focus=True, can_focus_children=True):
     MarkdownViewer.-show-table-of-contents > MarkdownTableOfContents {
         display: block;
     }
-
     """
 
     show_table_of_contents = reactive(True)
@@ -850,8 +848,8 @@ class MarkdownViewer(VerticalScroll, can_focus=True, can_focus_children=True):
         """Create a Markdown Viewer object.
 
         Args:
-            markdown: String containing Markdown, or None to leave blank. Defaults to None.
-            show_table_of_contents: Show a Table of COntents in a sidebar. Defaults to True.
+            markdown: String containing Markdown, or None to leave blank.
+            show_table_of_contents: Show a table of contents in a sidebar.
             name: The name of the widget.
             id: The ID of the widget in the DOM.
             classes: The CSS classes of the widget.
@@ -869,10 +867,10 @@ class MarkdownViewer(VerticalScroll, can_focus=True, can_focus_children=True):
 
     @property
     def table_of_contents(self) -> MarkdownTableOfContents:
-        """The Table of Contents widget"""
+        """The table of contents widget"""
         return self.query_one(MarkdownTableOfContents)
 
-    async def on_mount(self) -> None:
+    def _on_mount(self, _: Mount) -> None:
         if self._markdown is not None:
             self.document.update(self._markdown)
 
@@ -890,7 +888,7 @@ class MarkdownViewer(VerticalScroll, can_focus=True, can_focus_children=True):
         if self.navigator.forward():
             await self.document.load(self.navigator.location)
 
-    async def on_markdown_link_clicked(self, message: Markdown.LinkClicked) -> None:
+    async def _on_markdown_link_clicked(self, message: Markdown.LinkClicked) -> None:
         message.stop()
         await self.go(message.href)
 
@@ -901,7 +899,7 @@ class MarkdownViewer(VerticalScroll, can_focus=True, can_focus_children=True):
         yield MarkdownTableOfContents()
         yield Markdown(parser_factory=self._parser_factory)
 
-    def on_markdown_table_of_contents_updated(
+    def _on_markdown_table_of_contents_updated(
         self, message: Markdown.TableOfContentsUpdated
     ) -> None:
         self.query_one(
@@ -909,7 +907,7 @@ class MarkdownViewer(VerticalScroll, can_focus=True, can_focus_children=True):
         ).table_of_contents = message.table_of_contents
         message.stop()
 
-    def on_markdown_table_of_contents_selected(
+    def _on_markdown_table_of_contents_selected(
         self, message: Markdown.TableOfContentsSelected
     ) -> None:
         block_selector = f"#{message.block_id}"
