@@ -69,7 +69,6 @@ class Placeholder(Widget):
     Placeholder.-text {
         padding: 1;
     }
-
     """
 
     # Consecutive placeholders get assigned consecutive colors.
@@ -100,7 +99,7 @@ class Placeholder(Widget):
             label: The label to identify the placeholder.
                 If no label is present, uses the placeholder ID instead.
             variant: The variant of the placeholder.
-            name: The name of the placeholder. Defaults to None.
+            name: The name of the placeholder.
             id: The ID of the placeholder in the DOM.
             classes: A space separated string with the CSS classes
                 of the placeholder, if any.
@@ -156,11 +155,11 @@ class Placeholder(Widget):
             )
         return variant
 
-    def on_click(self) -> None:
+    async def _on_click(self, _: events.Click) -> None:
         """Click handler to cycle through the placeholder variants."""
         self.cycle_variant()
 
-    def on_resize(self, event: events.Resize) -> None:
+    def _on_resize(self, event: events.Resize) -> None:
         """Update the placeholder "size" variant with the new placeholder size."""
         self._renderables["size"] = self._SIZE_RENDER_TEMPLATE.format(*event.size)
         if self.variant == "size":
