@@ -1,4 +1,5 @@
 from pathlib import Path
+import sys
 
 import pytest
 
@@ -87,7 +88,7 @@ def test_input_and_focus(snap_compare):
 
 def test_buttons_render(snap_compare):
     # Testing button rendering. We press tab to focus the first button too.
-    assert snap_compare(WIDGET_EXAMPLES_DIR / "button.py", press=["tab"])
+    assert snap_compare(WIDGET_EXAMPLES_DIR / "button.py", press=["tab", "tab"])
 
 
 def test_placeholder_render(snap_compare):
@@ -116,11 +117,21 @@ def test_datatable_sort_multikey(snap_compare):
     assert snap_compare(SNAPSHOT_APPS_DIR / "data_table_sort.py", press=press)
 
 
+def test_datatable_remove_row(snap_compare):
+    press = ["r"]
+    assert snap_compare(SNAPSHOT_APPS_DIR / "data_table_remove_row.py", press=press)
+
+
 def test_datatable_labels_and_fixed_data(snap_compare):
     # Ensure that we render correctly when there are fixed rows/cols and labels.
     assert snap_compare(SNAPSHOT_APPS_DIR / "data_table_row_labels.py")
 
 
+def test_datatable_style_ordering(snap_compare):
+    # Regression test for https://github.com/Textualize/textual/issues/2061
+    assert snap_compare(SNAPSHOT_APPS_DIR / "data_table_style_order.py")
+
+
 def test_footer_render(snap_compare):
     assert snap_compare(WIDGET_EXAMPLES_DIR / "footer.py")
 
@@ -193,6 +204,30 @@ def test_option_list(snap_compare):
     assert snap_compare(WIDGET_EXAMPLES_DIR / "option_list_tables.py")
 
 
+def test_progress_bar_indeterminate(snap_compare):
+    assert snap_compare(WIDGET_EXAMPLES_DIR / "progress_bar_isolated_.py", press=["f"])
+
+
+def test_progress_bar_indeterminate_styled(snap_compare):
+    assert snap_compare(WIDGET_EXAMPLES_DIR / "progress_bar_styled_.py", press=["f"])
+
+
+def test_progress_bar_halfway(snap_compare):
+    assert snap_compare(WIDGET_EXAMPLES_DIR / "progress_bar_isolated_.py", press=["t"])
+
+
+def test_progress_bar_halfway_styled(snap_compare):
+    assert snap_compare(WIDGET_EXAMPLES_DIR / "progress_bar_styled_.py", press=["t"])
+
+
+def test_progress_bar_completed(snap_compare):
+    assert snap_compare(WIDGET_EXAMPLES_DIR / "progress_bar_isolated_.py", press=["u"])
+
+
+def test_progress_bar_completed_styled(snap_compare):
+    assert snap_compare(WIDGET_EXAMPLES_DIR / "progress_bar_styled_.py", press=["u"])
+
+
 # --- CSS properties ---
 # We have a canonical example for each CSS property that is shown in their docs.
 # If any of these change, something has likely broken, so snapshot each of them.
@@ -211,6 +246,11 @@ def test_css_property(file_name, snap_compare):
     assert snap_compare(path_to_app)
 
 
+def test_viewport_height_and_width_properties(snap_compare):
+    path_to_app = SNAPSHOT_APPS_DIR / "viewport_units.py"
+    assert snap_compare(path_to_app)
+
+
 def test_multiple_css(snap_compare):
     # Interaction between multiple CSS files and app-level/classvar CSS
     assert snap_compare("snapshot_apps/multiple_css/multiple_css.py")
@@ -254,7 +294,7 @@ def test_programmatic_scrollbar_gutter_change(snap_compare):
 
 
 def test_borders_preview(snap_compare):
-    assert snap_compare(CLI_PREVIEWS_DIR / "borders.py", press=["tab", "enter"])
+    assert snap_compare(CLI_PREVIEWS_DIR / "borders.py", press=["tab", "tab", "enter"])
 
 
 def test_colors_preview(snap_compare):
@@ -280,11 +320,19 @@ def test_demo(snap_compare):
     """Test the demo app (python -m textual)"""
     assert snap_compare(
         Path("../../src/textual/demo.py"),
-        press=["down", "down", "down"],
         terminal_size=(100, 30),
     )
 
 
+# def test_demo_with_keys(snap_compare):
+#     """Test the demo app (python -m textual)"""
+#     assert snap_compare(
+#         Path("../../src/textual/demo.py"),
+#         press=["down", "down", "down", "wait:500"],
+#         terminal_size=(100, 30),
+#     )
+
+
 def test_label_widths(snap_compare):
     """Test renderable widths are calculate correctly."""
     assert snap_compare(SNAPSHOT_APPS_DIR / "label_widths.py")
@@ -310,7 +358,9 @@ def test_disabled_widgets(snap_compare):
 
 
 def test_focus_component_class(snap_compare):
-    assert snap_compare(SNAPSHOT_APPS_DIR / "focus_component_class.py", press=["tab"])
+    assert snap_compare(
+        SNAPSHOT_APPS_DIR / "focus_component_class.py", press=["tab", "tab"]
+    )
 
 
 def test_line_api_scrollbars(snap_compare):
@@ -386,3 +436,41 @@ def test_modal_dialog_bindings(snap_compare):
 def test_dock_scroll(snap_compare):
     # https://github.com/Textualize/textual/issues/2188
     assert snap_compare(SNAPSHOT_APPS_DIR / "dock_scroll.py", terminal_size=(80, 25))
+
+
+def test_auto_fr(snap_compare):
+    # https://github.com/Textualize/textual/issues/2220
+    assert snap_compare(SNAPSHOT_APPS_DIR / "auto_fr.py", terminal_size=(80, 25))
+
+
+def test_fr_margins(snap_compare):
+    # https://github.com/Textualize/textual/issues/2220
+    assert snap_compare(SNAPSHOT_APPS_DIR / "fr_margins.py", terminal_size=(80, 25))
+
+
+def test_scroll_visible(snap_compare):
+    # https://github.com/Textualize/textual/issues/2181
+    assert snap_compare(SNAPSHOT_APPS_DIR / "scroll_visible.py", press=["t"])
+
+
+@pytest.mark.xfail(
+    reason="Unpredictable while https://github.com/Textualize/textual/issues/2254 is open."
+)
+def test_scroll_to_center(snap_compare):
+    # READ THIS IF THIS TEST FAILS:
+    # While https://github.com/Textualize/textual/issues/2254 is open, the snapshot
+    # this is being compared against is INCORRECT.
+    # The correct output for this snapshot test would show a couple of containers
+    # scrolled so that the red string >>bullseye<< is centered on the screen.
+    # When this snapshot "breaks" because #2254 is fixed, this snapshot can be updated.
+    assert snap_compare(SNAPSHOT_APPS_DIR / "scroll_to_center.py", press=["s"])
+
+
+def test_quickly_change_tabs(snap_compare):
+    # https://github.com/Textualize/textual/issues/2229
+    assert snap_compare(SNAPSHOT_APPS_DIR / "quickly_change_tabs.py", press=["p"])
+
+
+def test_fr_unit_with_min(snap_compare):
+    # https://github.com/Textualize/textual/issues/2378
+    assert snap_compare(SNAPSHOT_APPS_DIR / "fr_with_min.py")
